==> OccuPy-0.1.8rc2.tar.gz: OccuPy-0.1.8rc2/docs/gallery/index.md <==
# Showcase / gallery 

Different examples of how Occupy has been used, and helped to visualise and analyze cryo-EM maps. 

---

## From the Paper

These are examples of how figures were generated for the main OccuPy paper. In some cases instructions are provided 
to reproduce the results. 

<div class="gallery-image">

    <div class="img-box">
    <a class="reference internal" href="synthetic" style="color:#FFFFFF;">
      <img src="thumbs/synthetic.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Synthetic input</p>
            <p class="opacity-low">PDB-1UXI</p>
        </div>
      </div> 
    </a>
    </div>

    <div class="img-box">
    <a class="reference internal" href="mass" style="color:#FFFFFF;">
      <img src="thumbs/mass.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Mass effects</p>
          <p class="opacity-low">EMD-33707</p></p>
        </div>
      </div>    
    </a>
    </div>     

    <div class="img-box">
    <!--<a class="reference internal" href="membrane" style="color:#FFFFFF;">
    -->
      <img src="thumbs/membrane.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Membrane protein <br> (COMING SOON)</p>
          <p class="opacity-low">EMD-23015</p></p>
        </div>
      </div>    
    </a>
    </div>  

    <div class="img-box">
    <!--<a class="reference internal" href="modification" style="color:#FFFFFF;">
    -->
      <img src="thumbs/modification.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Modification <br> (COMING SOON)</p>
          <p class="opacity-low">EMD-14085</p></p>
        </div>
      </div>    
    </a>
    </div>   

    <div class="img-box">
    <!--<a class="reference internal" href="resolution" style="color:#FFFFFF;">
    -->
      <img src="thumbs/resolution.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Resolution <br> (COMING SOON)</p>
          <p class="opacity-low">EMD-13015</p></p>
        </div>
      </div>    
    </a>
    </div>  

</div>

---

## By the team 

<div class="gallery-image">

    <div class="img-box" >
    <a class="reference internal" href="highres" style="color:#FFFFFF;">
      <img src="thumbs/high-res.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>At high resolution</p>
          <p class="opacity-low">EMD-33707</p></p>
        </div>
      </div>    
    </a>
    </div>  

    <div class="img-box">
    <!--<a class="reference internal" href="ribosome" style="color:#FFFFFF;">
    -->
      <img src="thumbs/ribo.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>A ribosome <br> (COMING SOON)</p>
          <p class="opacity-low">EMD-3943</p></p>
        </div>
      </div>    
    </a>
    </div>  

    <div class="img-box">
    <!--<a class="reference internal" href="spike" style="color:#FFFFFF;">
    -->
    <img src="thumbs/spike.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>A viral spike <br> (COMING SOON)</p>
          <p class="opacity-low">Unpublished data</p></p>
        </div>
      </div>    
    </a>
    </div>  

</div>


[//]: # (<div id="download_links"></div>)

[//]: # ()
[//]: # ([:fontawesome-solid-download: Download all examples in Python source code: gallery_python.zip]&#40;./gallery_python.zip&#41;{ .md-button .center})

[//]: # ()
[//]: # ([:fontawesome-solid-download: Download all examples in Jupyter notebooks: gallery_jupyter.zip]&#40;./gallery_jupyter.zip&#41;{ .md-button .center})

[//]: # ()
[//]: # ()
[//]: # ([Gallery generated by mkdocs-gallery]&#40;https://mkdocs-gallery.github.io&#41;{: .mkd-glr-signature })

==> OccuPy-0.1.12.tar.gz: OccuPy-0.1.12/docs/gallery/index.md <==
# Showcase / gallery 

Here you will find different examples of how Occupy has been used, and helped to visualise and analyze cryo-EM maps. 
The first section details how to use OccuPy to reproduce the images in the paper. If you have cases where it has 
been useful, please consider letting one of the developer know so that we can showcase it here. 

---

## From the Paper

These are examples of how figures were generated for the main OccuPy paper. In some cases instructions are provided 
to reproduce the results. 

<div class="gallery-image">

    <div class="img-box">
    <a class="reference internal" href="synthetic" style="color:#FFFFFF;">
      <img src="thumbs/synthetic.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Synthetic input</p>
            <p class="opacity-low">PDB-1UXI</p>
        </div>
      </div> 
    </a>
    </div>

    <div class="img-box">
    <a class="reference internal" href="mass" style="color:#FFFFFF;">
      <img src="thumbs/mass.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Mass effects</p>
          <p class="opacity-low">EMD-33707</p></p>
        </div>
      </div>    
    </a>
    </div>     

    <div class="img-box">
    <a class="reference internal" href="modification" style="color:#FFFFFF;">
      <img src="thumbs/modification.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Modification</p>
          <p class="opacity-low">EMD-14085</p></p>
        </div>
      </div>    
    </a>
    </div>   

    <div class="img-box">
    <a class="reference internal" href="membrane" style="color:#FFFFFF;">
      <img src="thumbs/membrane.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Membrane</p>
          <p class="opacity-low">EMD-23015</p></p>
        </div>
      </div>    
    </a>
    </div>

    <div class="img-box">
    <!--<a class="reference internal" href="resolution" style="color:#FFFFFF;">
    -->
      <img src="thumbs/resolution.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>Resolution <br> (COMING SOON)</p>
          <p class="opacity-low">EMD-13015</p></p>
        </div>
      </div>    
    </a>
    </div>  

</div>

---

## By the team 

<div class="gallery-image">

    <div class="img-box" >
    <a class="reference internal" href="highres" style="color:#FFFFFF;">
      <img src="thumbs/high-res.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>At high resolution</p>
          <p class="opacity-low">EMD-33707</p></p>
        </div>
      </div>    
    </a>
    </div>  

    <div class="img-box">
    <!--<a class="reference internal" href="ribosome" style="color:#FFFFFF;">
    -->
      <img src="thumbs/ribo.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>A ribosome <br> (COMING SOON)</p>
          <p class="opacity-low">EMD-3943</p></p>
        </div>
      </div>    
    </a>
    </div>  

    <div class="img-box">
    <!--<a class="reference internal" href="spike" style="color:#FFFFFF;">
    -->
    <img src="thumbs/spike.png" alt="" />
      <div class="transparent-box">
        <div class="caption">
          <p>A viral spike <br> (COMING SOON)</p>
          <p class="opacity-low">Unpublished data</p></p>
        </div>
      </div>    
    </a>
    </div>  

</div>

---

## By the community
